@@ -32,246 +32,7 @@ import xarray as xr
 
 from pyresample.area_config import create_area_def
 from pyresample.geometry import AreaDefinition, SwathDefinition
-from pyresample.gradient import ResampleBlocksGradientSearchResampler
-
-
-class TestOGradientResampler:
-    """Test case for the gradient resampling."""
-
-    def setup_method(self):
-        """Set up the test case."""
-        from pyresample.gradient import StackingGradientSearchResampler
-        self.src_area = AreaDefinition('dst', 'dst area', None,
-                                       {'ellps': 'WGS84', 'h': '35785831', 'proj': 'geos'},
-                                       100, 100,
-                                       (5550000.0, 5550000.0, -5550000.0, -5550000.0))
-        self.src_swath = SwathDefinition(*self.src_area.get_lonlats())
-        self.dst_area = AreaDefinition('euro40', 'euro40', None,
-                                       {'proj': 'stere', 'lon_0': 14.0,
-                                        'lat_0': 90.0, 'lat_ts': 60.0,
-                                        'ellps': 'bessel'},
-                                       102, 102,
-                                       (-2717181.7304994687, -5571048.14031214,
-                                        1378818.2695005313, -1475048.1403121399))
-        self.dst_swath = SwathDefinition(*self.dst_area.get_lonlats())
-
-        with warnings.catch_warnings():
-            warnings.filterwarnings("ignore", message=".*which is still EXPERIMENTAL.*", category=UserWarning)
-            self.resampler = StackingGradientSearchResampler(self.src_area, self.dst_area)
-            self.swath_resampler = StackingGradientSearchResampler(self.src_swath, self.dst_area)
-            self.area_to_swath_resampler = StackingGradientSearchResampler(self.src_area, self.dst_swath)
-
-    def test_get_projection_coordinates_area_to_area(self):
-        """Check that the coordinates are initialized, for area -> area."""
-        assert self.resampler.prj is None
-        self.resampler._get_projection_coordinates((10, 10))
-        cdst_x = self.resampler.dst_x.compute()
-        cdst_y = self.resampler.dst_y.compute()
-        assert np.allclose(np.min(cdst_x), -2022632.1675016289)
-        assert np.allclose(np.max(cdst_x), 2196052.591296284)
-        assert np.allclose(np.min(cdst_y), 3517933.413092212)
-        assert np.allclose(np.max(cdst_y), 5387038.893400168)
-        assert self.resampler.use_input_coords
-        assert self.resampler.prj is not None
-
-    def test_get_projection_coordinates_swath_to_area(self):
-        """Check that the coordinates are initialized, for swath -> area."""
-        assert self.swath_resampler.prj is None
-        self.swath_resampler._get_projection_coordinates((10, 10))
-        cdst_x = self.swath_resampler.dst_x.compute()
-        cdst_y = self.swath_resampler.dst_y.compute()
-        assert np.allclose(np.min(cdst_x), -2697103.29912692)
-        assert np.allclose(np.max(cdst_x), 1358739.8381279823)
-        assert np.allclose(np.min(cdst_y), -5550969.708939591)
-        assert np.allclose(np.max(cdst_y), -1495126.5716846888)
-        assert self.swath_resampler.use_input_coords is False
-        assert self.swath_resampler.prj is not None
-
-    def test_get_gradients(self):
-        """Test that coordinate gradients are computed correctly."""
-        self.resampler._get_projection_coordinates((10, 10))
-        assert self.resampler.src_gradient_xl is None
-        self.resampler._get_gradients()
-        assert self.resampler.src_gradient_xl.compute().max() == 0.0
-        assert self.resampler.src_gradient_xp.compute().max() == -111000.0
-        assert self.resampler.src_gradient_yl.compute().max() == 111000.0
-        assert self.resampler.src_gradient_yp.compute().max() == 0.0
-
-    def test_get_chunk_mappings(self):
-        """Test that chunk overlap, and source and target slices are correct."""
-        chunks = (10, 10)
-        num_chunks = np.prod(chunks)
-        self.resampler._get_projection_coordinates(chunks)
-        self.resampler._get_gradients()
-        assert self.resampler.coverage_status is None
-        self.resampler.get_chunk_mappings()
-        # 8 source chunks overlap the target area
-        covered_src_chunks = np.array([38, 39, 48, 49, 58, 59, 68, 69])
-        res = np.where(self.resampler.coverage_status)[0]
-        assert np.all(res == covered_src_chunks)
-        # All *num_chunks* should have values in the lists
-        assert len(self.resampler.coverage_status) == num_chunks
-        assert len(self.resampler.src_slices) == num_chunks
-        assert len(self.resampler.dst_slices) == num_chunks
-        assert len(self.resampler.dst_mosaic_locations) == num_chunks
-        # There's only one output chunk, and the covered source chunks
-        # should have destination locations of (0, 0)
-        res = np.array(self.resampler.dst_mosaic_locations)[covered_src_chunks]
-        assert all([all(loc == (0, 0)) for loc in list(res)])
-
-    def test_get_src_poly_area(self):
-        """Test defining source chunk polygon for AreaDefinition."""
-        chunks = (10, 10)
-        self.resampler._get_projection_coordinates(chunks)
-        self.resampler._get_gradients()
-        poly = self.resampler._get_src_poly(0, 40, 0, 40)
-        assert np.allclose(poly.area, 12365358458842.43)
-
-    def test_get_src_poly_swath(self):
-        """Test defining source chunk polygon for SwathDefinition."""
-        chunks = (10, 10)
-        self.swath_resampler._get_projection_coordinates(chunks)
-        self.swath_resampler._get_gradients()
-        # SwathDefinition can't be sliced, so False is returned
-        poly = self.swath_resampler._get_src_poly(0, 40, 0, 40)
-        assert poly is False
-
-    @mock.patch('pyresample.gradient.get_polygon')
-    def test_get_dst_poly_area(self, get_polygon):
-        """Test defining destination chunk polygon."""
-        chunks = (10, 10)
-        self.resampler._get_projection_coordinates(chunks)
-        self.resampler._get_gradients()
-        # First call should make a call to get_polygon()
-        self.resampler._get_dst_poly('idx1', 0, 10, 0, 10)
-        assert get_polygon.call_count == 1
-        assert 'idx1' in self.resampler.dst_polys
-        # The second call to the same index should come from cache
-        self.resampler._get_dst_poly('idx1', 0, 10, 0, 10)
-        assert get_polygon.call_count == 1
-
-    def test_get_dst_poly_swath(self):
-        """Test defining dst chunk polygon for SwathDefinition."""
-        chunks = (10, 10)
-        self.area_to_swath_resampler._get_projection_coordinates(chunks)
-        self.area_to_swath_resampler._get_gradients()
-        # SwathDefinition can't be sliced, so False is returned
-        self.area_to_swath_resampler._get_dst_poly('idx2', 0, 10, 0, 10)
-        assert self.area_to_swath_resampler.dst_polys['idx2'] is False
-
-    def test_filter_data(self):
-        """Test filtering chunks that do not overlap."""
-        chunks = (10, 10)
-        self.resampler._get_projection_coordinates(chunks)
-        self.resampler._get_gradients()
-        self.resampler.get_chunk_mappings()
-
-        # Basic filtering.  There should be 8 dask arrays that each
-        # have a shape of (10, 10)
-        res = self.resampler._filter_data(self.resampler.src_x)
-        valid = [itm for itm in res if itm is not None]
-        assert len(valid) == 8
-        shapes = [arr.shape for arr in valid]
-        for shp in shapes:
-            assert shp == (10, 10)
-
-        # Destination x/y coordinate array filtering.  Again, 8 dask
-        # arrays each with shape (102, 102)
-        res = self.resampler._filter_data(self.resampler.dst_x, is_src=False)
-        valid = [itm for itm in res if itm is not None]
-        assert len(valid) == 8
-        shapes = [arr.shape for arr in valid]
-        for shp in shapes:
-            assert shp == (102, 102)
-
-        # Add a dimension to the given dataset
-        data = da.random.random(self.src_area.shape)
-        res = self.resampler._filter_data(data, add_dim=True)
-        valid = [itm for itm in res if itm is not None]
-        assert len(valid) == 8
-        shapes = [arr.shape for arr in valid]
-        for shp in shapes:
-            assert shp == (1, 10, 10)
-
-        # 1D and 3+D should raise NotImplementedError
-        data = da.random.random((3,))
-        try:
-            res = self.resampler._filter_data(data, add_dim=True)
-            raise IndexError
-        except NotImplementedError:
-            pass
-        data = da.random.random((3, 3, 3, 3))
-        try:
-            res = self.resampler._filter_data(data, add_dim=True)
-            raise IndexError
-        except NotImplementedError:
-            pass
-
-    def test_resample_area_to_area_2d(self):
-        """Resample area to area, 2d."""
-        data = xr.DataArray(da.ones(self.src_area.shape, dtype=np.float64),
-                            dims=['y', 'x'])
-        res = self.resampler.compute(
-            data, method='bil').compute(scheduler='single-threaded')
-        assert res.shape == self.dst_area.shape
-        assert np.allclose(res, 1)
-
-    def test_resample_area_to_area_2d_fill_value(self):
-        """Resample area to area, 2d, use fill value."""
-        data = xr.DataArray(da.full(self.src_area.shape, np.nan,
-                                    dtype=np.float64), dims=['y', 'x'])
-        res = self.resampler.compute(
-            data, method='bil',
-            fill_value=2.0).compute(scheduler='single-threaded')
-        assert res.shape == self.dst_area.shape
-        assert np.allclose(res, 2.0)
-
-    def test_resample_area_to_area_3d(self):
-        """Resample area to area, 3d."""
-        data = xr.DataArray(da.ones((3, ) + self.src_area.shape,
-                                    dtype=np.float64) *
-                            np.array([1, 2, 3])[:, np.newaxis, np.newaxis],
-                            dims=['bands', 'y', 'x'])
-        res = self.resampler.compute(
-            data, method='bil').compute(scheduler='single-threaded')
-        assert res.shape == (3, ) + self.dst_area.shape
-        assert np.allclose(res[0, :, :], 1.0)
-        assert np.allclose(res[1, :, :], 2.0)
-        assert np.allclose(res[2, :, :], 3.0)
-
-    def test_resample_area_to_area_3d_single_channel(self):
-        """Resample area to area, 3d with only a single band."""
-        data = xr.DataArray(da.ones((1, ) + self.src_area.shape,
-                                    dtype=np.float64),
-                            dims=['bands', 'y', 'x'])
-        res = self.resampler.compute(
-            data, method='bil').compute(scheduler='single-threaded')
-        assert res.shape == (1, ) + self.dst_area.shape
-        assert np.allclose(res[0, :, :], 1.0)
-
-    def test_resample_swath_to_area_2d(self):
-        """Resample swath to area, 2d."""
-        data = xr.DataArray(da.ones(self.src_swath.shape, dtype=np.float64),
-                            dims=['y', 'x'])
-        with np.errstate(invalid="ignore"):  # 'inf' space pixels cause runtime warnings
-            res = self.swath_resampler.compute(
-                data, method='bil').compute(scheduler='single-threaded')
-        assert res.shape == self.dst_area.shape
-        assert not np.all(np.isnan(res))
-
-    def test_resample_swath_to_area_3d(self):
-        """Resample area to area, 3d."""
-        data = xr.DataArray(da.ones((3, ) + self.src_swath.shape,
-                                    dtype=np.float64) *
-                            np.array([1, 2, 3])[:, np.newaxis, np.newaxis],
-                            dims=['bands', 'y', 'x'])
-        with np.errstate(invalid="ignore"):  # 'inf' space pixels cause runtime warnings
-            res = self.swath_resampler.compute(
-                data, method='bil').compute(scheduler='single-threaded')
-        assert res.shape == (3, ) + self.dst_area.shape
-        for i in range(res.shape[0]):
-            arr = np.ravel(res[i, :, :])
-            assert np.allclose(arr[np.isfinite(arr)], float(i + 1))
+from pyresample.gradient import ResampleBlocksGradientSearchResampler, create_gradient_search_resampler
 
 
 class TestRBGradientSearchResamplerArea2Area:
@@ -495,12 +256,81 @@ class TestRBGradientSearchResamplerArea2Area:
         assert res.shape == dst_area.shape
 
 
-class TestRBGradientSearchResamplerArea2Swath:
-    """Test RBGradientSearchResampler for the Swath to Area case."""
+class TestRBGradientSearchResamplerSwath2Area:
+    """Test RBGradientSearchResampler for the Area to Swath case."""
 
     def setup_method(self):
         """Set up the test case."""
-        chunks = 20
+        lons, lats = np.meshgrid(np.linspace(0, 20, 100), np.linspace(45, 66, 100))
+        self.src_swath = SwathDefinition(lons, lats, crs="WGS84")
+        lons, lats = self.src_swath.get_lonlats(chunks=10)
+        lons = xr.DataArray(lons, dims=["y", "x"])
+        lats = xr.DataArray(lats, dims=["y", "x"])
+        self.src_swath_dask = SwathDefinition(lons, lats)
+        self.dst_area = AreaDefinition('euro40', 'euro40', None,
+                                       {'proj': 'stere', 'lon_0': 14.0,
+                                        'lat_0': 90.0, 'lat_ts': 60.0,
+                                        'ellps': 'bessel'},
+                                       102, 102,
+                                       (-2717181.7304994687, -5571048.14031214,
+                                        1378818.2695005313, -1475048.1403121399))
+
+    @pytest.mark.parametrize("input_dtype", (np.float32, np.float64))
+    def test_resample_swath_to_area_2d(self, input_dtype):
+        """Resample swath to area, 2d."""
+        swath_resampler = ResampleBlocksGradientSearchResampler(self.src_swath_dask, self.dst_area)
+
+        data = xr.DataArray(da.ones(self.src_swath.shape, dtype=input_dtype),
+                            dims=['y', 'x'])
+        with np.errstate(invalid="ignore"):  # 'inf' space pixels cause runtime warnings
+            swath_resampler.precompute()
+            res_xr = swath_resampler.compute(data, method='bilinear')
+            res_np = res_xr.compute(scheduler='single-threaded')
+
+        assert res_xr.dtype == data.dtype
+        assert res_np.dtype == data.dtype
+        assert res_xr.shape == self.dst_area.shape
+        assert res_np.shape == self.dst_area.shape
+        assert type(res_xr) is type(data)
+        assert type(res_xr.data) is type(data.data)
+        assert not np.all(np.isnan(res_np))
+
+    @pytest.mark.parametrize("input_dtype", (np.float32, np.float64))
+    def test_resample_swath_to_area_3d(self, input_dtype):
+        """Resample area to area, 3d."""
+        swath_resampler = ResampleBlocksGradientSearchResampler(self.src_swath_dask, self.dst_area)
+
+        data = xr.DataArray(da.ones((3, ) + self.src_swath.shape,
+                                    dtype=input_dtype) *
+                            np.array([1, 2, 3])[:, np.newaxis, np.newaxis],
+                            dims=['bands', 'y', 'x'])
+        with np.errstate(invalid="ignore"):  # 'inf' space pixels cause runtime warnings
+            swath_resampler.precompute()
+            res_xr = swath_resampler.compute(data, method='bilinear')
+            res_np = res_xr.compute(scheduler='single-threaded')
+
+        assert res_xr.dtype == data.dtype
+        assert res_np.dtype == data.dtype
+        assert res_xr.shape == (3, ) + self.dst_area.shape
+        assert res_np.shape == (3, ) + self.dst_area.shape
+        assert type(res_xr) is type(data)
+        assert type(res_xr.data) is type(data.data)
+        for i in range(res_np.shape[0]):
+            arr = np.ravel(res_np[i, :, :])
+            assert np.allclose(arr[np.isfinite(arr)], float(i + 1))
+
+
+class TestRBGradientSearchResamplerArea2Swath:
+    """Test RBGradientSearchResampler for the Area to Swath case."""
+
+    def setup_method(self):
+        """Set up the test case."""
+        lons, lats = np.meshgrid(np.linspace(0, 20, 100), np.linspace(45, 66, 100))
+        self.dst_swath = SwathDefinition(lons, lats, crs="WGS84")
+        lons, lats = self.dst_swath.get_lonlats(chunks=10)
+        lons = xr.DataArray(lons, dims=["y", "x"])
+        lats = xr.DataArray(lats, dims=["y", "x"])
+        self.dst_swath_dask = SwathDefinition(lons, lats)
 
         self.src_area = AreaDefinition('euro40', 'euro40', None,
                                        {'proj': 'stere', 'lon_0': 14.0,
@@ -510,34 +340,49 @@ class TestRBGradientSearchResamplerArea2Swath:
                                        (-2717181.7304994687, -5571048.14031214,
                                         1378818.2695005313, -1475048.1403121399))
 
-        self.dst_area = AreaDefinition(
-            'omerc_otf',
-            'On-the-fly omerc area',
-            None,
-            {'alpha': '8.99811271718795',
-             'ellps': 'sphere',
-             'gamma': '0',
-             'k': '1',
-             'lat_0': '0',
-             'lonc': '13.8096029486222',
-             'proj': 'omerc',
-             'units': 'm'},
-            50, 100,
-            (-1461111.3603, 3440088.0459, 1534864.0322, 9598335.0457)
-        )
+    @pytest.mark.parametrize("input_dtype", (np.float32, np.float64))
+    def test_resample_area_to_swath_2d(self, input_dtype):
+        """Resample swath to area, 2d."""
+        swath_resampler = create_gradient_search_resampler(self.src_area, self.dst_swath_dask)
 
-        self.lons, self.lats = self.dst_area.get_lonlats(chunks=chunks)
-        xrlons = xr.DataArray(self.lons.persist())
-        xrlats = xr.DataArray(self.lats.persist())
-        self.dst_swath = SwathDefinition(xrlons, xrlats)
+        data = xr.DataArray(da.ones(self.src_area.shape, dtype=input_dtype),
+                            dims=['y', 'x'])
+        with np.errstate(invalid="ignore"):  # 'inf' space pixels cause runtime warnings
+            swath_resampler.precompute()
+            res_xr = swath_resampler.compute(data, method='bilinear')
+            res_np = res_xr.compute(scheduler='single-threaded')
 
-    def test_resampling_to_swath_is_not_implemented(self):
-        """Test that resampling to swath is not working yet."""
-        from pyresample.gradient import ResampleBlocksGradientSearchResampler
+        assert res_xr.dtype == data.dtype
+        assert res_np.dtype == data.dtype
+        assert res_xr.shape == self.dst_swath.shape
+        assert res_np.shape == self.dst_swath.shape
+        assert type(res_xr) is type(data)
+        assert type(res_xr.data) is type(data.data)
+        assert not np.all(np.isnan(res_np))
 
-        with pytest.raises(NotImplementedError):
-            ResampleBlocksGradientSearchResampler(self.src_area,
-                                                  self.dst_swath)
+    @pytest.mark.parametrize("input_dtype", (np.float32, np.float64))
+    def test_resample_area_to_swath_3d(self, input_dtype):
+        """Resample area to area, 3d."""
+        swath_resampler = ResampleBlocksGradientSearchResampler(self.src_area, self.dst_swath_dask)
+
+        data = xr.DataArray(da.ones((3, ) + self.src_area.shape,
+                                    dtype=input_dtype) *
+                            np.array([1, 2, 3])[:, np.newaxis, np.newaxis],
+                            dims=['bands', 'y', 'x'])
+        with np.errstate(invalid="ignore"):  # 'inf' space pixels cause runtime warnings
+            swath_resampler.precompute()
+            res_xr = swath_resampler.compute(data, method='bilinear')
+            res_np = res_xr.compute(scheduler='single-threaded')
+
+        assert res_xr.dtype == data.dtype
+        assert res_np.dtype == data.dtype
+        assert res_xr.shape == (3, ) + self.dst_swath.shape
+        assert res_np.shape == (3, ) + self.dst_swath.shape
+        assert type(res_xr) is type(data)
+        assert type(res_xr.data) is type(data.data)
+        for i in range(res_np.shape[0]):
+            arr = np.ravel(res_np[i, :, :])
+            assert np.allclose(arr[np.isfinite(arr)], float(i + 1))
 
 
 class TestEnsureDataArray(unittest.TestCase):
@@ -582,103 +427,6 @@ class TestEnsureDataArray(unittest.TestCase):
         decorated('bla', data)
 
 
-def test_check_overlap():
-    """Test overlap check returning correct results."""
-    from shapely.geometry import Polygon
-
-    from pyresample.gradient import check_overlap
-
-    # If either of the polygons is False, True is returned
-    assert check_overlap(False, 3) is True
-    assert check_overlap('eggs', False) is True
-    assert check_overlap(False, False) is True
-
-    # If either the polygons is None, False is returned
-    assert check_overlap(None, 'bacon') is False
-    assert check_overlap('spam', None) is False
-    assert check_overlap(None, None) is False
-
-    # If the polygons overlap, True is returned
-    poly1 = Polygon(((0, 0), (0, 1), (1, 1), (1, 0)))
-    poly2 = Polygon(((-1, -1), (-1, 1), (1, 1), (1, -1)))
-    assert check_overlap(poly1, poly2) is True
-
-    # If the polygons do not overlap, False is returned
-    poly2 = Polygon(((5, 5), (6, 5), (6, 6), (5, 6)))
-    assert check_overlap(poly1, poly2) is False
-
-
-def test_get_border_lonlats_geos():
-    """Test that correct methods are called in get_border_lonlats() with geos inputs."""
-    from pyresample.gradient import get_border_lonlats
-    geo_def = AreaDefinition("", "", "",
-                             "+proj=geos +h=1234567", 2, 2, [1, 2, 3, 4])
-    with mock.patch("pyresample.gradient.get_geostationary_bounding_box_in_lonlats") as get_geostationary_bounding_box:
-        get_geostationary_bounding_box.return_value = 1, 2
-        res = get_border_lonlats(geo_def)
-    assert res == (1, 2)
-    get_geostationary_bounding_box.assert_called_with(geo_def, 3600)
-
-
-def test_get_border_lonlats():
-    """Test that correct methods are called in get_border_lonlats()."""
-    from pyresample.boundary import SimpleBoundary
-    from pyresample.gradient import get_border_lonlats
-    lon_sides = SimpleBoundary(side1=np.array([1]), side2=np.array([2]),
-                               side3=np.array([3]), side4=np.array([4]))
-    lat_sides = SimpleBoundary(side1=np.array([1]), side2=np.array([2]),
-                               side3=np.array([3]), side4=np.array([4]))
-    geo_def = AreaDefinition("", "", "",
-                             "+proj=lcc +lat_1=25 +lat_2=25", 2, 2, [1, 2, 3, 4])
-    with mock.patch.object(geo_def, "get_boundary_lonlats") as get_boundary_lonlats:
-        get_boundary_lonlats.return_value = lon_sides, lat_sides
-        lon_b, lat_b = get_border_lonlats(geo_def)
-    assert np.all(lon_b == np.array([1, 2, 3, 4]))
-    assert np.all(lat_b == np.array([1, 2, 3, 4]))
-
-
-@mock.patch('pyresample.gradient.Polygon')
-@mock.patch('pyresample.gradient.get_border_lonlats')
-def test_get_polygon(get_border_lonlats, Polygon):
-    """Test polygon creation."""
-    from pyresample.gradient import get_polygon
-
-    # Valid polygon
-    get_border_lonlats.return_value = (1, 2)
-    geo_def = mock.MagicMock()
-    prj = mock.MagicMock()
-    x_borders = [0, 0, 1, 1]
-    y_borders = [0, 1, 1, 0]
-    boundary = [(0, 0), (0, 1), (1, 1), (1, 0)]
-    prj.return_value = (x_borders, y_borders)
-    poly = mock.MagicMock(area=2.0)
-    Polygon.return_value = poly
-    res = get_polygon(prj, geo_def)
-    get_border_lonlats.assert_called_with(geo_def)
-    prj.assert_called_with(1, 2)
-    Polygon.assert_called_with(boundary)
-    assert res is poly
-
-    # Some border points are invalid, those should have been removed
-    x_borders = [np.inf, 0, 0, 0, 1, np.nan, 2]
-    y_borders = [-1, 0, np.nan, 1, 1, np.nan, -1]
-    boundary = [(0, 0), (0, 1), (1, 1), (2, -1)]
-    prj.return_value = (x_borders, y_borders)
-    res = get_polygon(prj, geo_def)
-    Polygon.assert_called_with(boundary)
-    assert res is poly
-
-    # Polygon area is NaN
-    poly.area = np.nan
-    res = get_polygon(prj, geo_def)
-    assert res is None
-
-    # Polygon area is 0.0
-    poly.area = 0.0
-    res = get_polygon(prj, geo_def)
-    assert res is None
-
-
 @mock.patch('pyresample.gradient.one_step_gradient_search')
 def test_gradient_resample_data(one_step_gradient_search):
     """Test that one_step_gradient_search() is called with proper array shapes."""
@@ -813,21 +561,6 @@ def test_concatenate_chunks():
     assert res.shape == (3, 8, 6)
 
 
-@mock.patch('pyresample.gradient.da')
-def test_concatenate_chunks_stack_calls(dask_da):
-    """Test that stacking is called the correct times in chunk concatenation."""
-    from pyresample.gradient import _concatenate_chunks
-
-    chunks = {(0, 0): [np.ones((1, 5, 4)), np.zeros((1, 5, 4))],
-              (1, 0): [np.zeros((1, 5, 2))],
-              (1, 1): [np.full((1, 3, 2), 0.5)],
-              (0, 1): [np.full((1, 3, 4), -1)]}
-    _ = _concatenate_chunks(chunks)
-    dask_da.stack.assert_called_once_with(chunks[(0, 0)], axis=-1)
-    dask_da.nanmax.assert_called_once()
-    assert 'axis=2' in str(dask_da.concatenate.mock_calls[-1])
-
-
 class TestGradientCython():
     """Test the core gradient features."""
 
